# Flask-Misaka

![Build Status](https://github.com/singingwolfboy/flask-misaka/workflows/Test/badge.svg) [![Coverage Status](http://codecov.io/github/singingwolfboy/flask-misaka/coverage.svg?branch=master)](http://codecov.io/github/singingwolfboy/flask-misaka?branch=master) [![Documentation Status](https://readthedocs.org/projects/flask-misaka/badge/?version=latest)](http://flask-misaka.readthedocs.org/en/latest/?badge=latest)

A simple Flask extension to integrate the [Misaka](http://misaka.61924.nl)
module, which is a Python interface to the excellent
[Hoedown](https://github.com/hoedown/hoedown) markdown-parsing library.
Check the [Misaka changelog](http://misaka.61924.nl/changelog.html)
to keep up with new features.

The full documentation for this project is built using Sphinx; you can also
check out [a pre-built version hosted on RTD](https://flask-misaka.readthedocs.org/en/latest/).
